/*******************************************************************************
 * Copyright (c) 2000, 2003 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.hyades.execution.datapool;

/**
 * This class defines the base interface for all named elements.  Each named
 * element has a standard set of associated properties.  Any undefined property
 * will return <code>null</code> for the property value.
 * 
 * @see	IDatapool
 * @see IDatapoolEquivalenceClass
 * @see	IDatapoolVariable
 */
public interface INamedElement
{
	
	/**
	 * Accessor method for the GUID for the element.  <code>null</code>
	 * is returned if no GUID has been defined for the element.
	 * 
	 * @see #setId(String)
	 */
	public String getId();
	
	/**
	 * Specify the GUID for the associated element.
	 * 
	 * @see #getId()
	 */
	public void setId(String id);
	
	/**
	 * Accessor method for the name of the element.  <code>null</code>
	 * is returned if no name has been defined for the element.
	 * 
	 * @see #setName(String)
	 */
	public String getName();
	
	/**
	 * Specify the name for the associated element.
	 * 
	 * @see #getName()
	 */
	public void setName(String name);
	
	/**
	 * Accessor for the description associated with the element.
	 * <code>null</code> is returned if no description has been associated 
	 * with the element.
	 * 
	 * @see	#setDescription(String)
	 */
	public String getDescription();
	
	/**
	 * Specify the description for the associated element.
	 * 
	 * @see	#getDescription()
	 */
	public void setDescription(String description);
	
}
